@@ -8,6 +8,12 @@ import tarfile
 from functools import cmp_to_key
 from gzip import GzipFile
 
+from cleo import argument
+from cleo import option
+
+from ..command import Command
+
+
 try:
     from urllib.error import HTTPError
     from urllib.request import urlopen
@@ -15,19 +21,18 @@ except ImportError:
     from urllib2 import HTTPError
     from urllib2 import urlopen
 
-from ..command import Command
-
 
 class SelfUpdateCommand(Command):
-    """
-    Updates poetry to the latest version.
 
-    self:update
-        { version? : The version to update to. }
-        { --preview : Install prereleases. }
-    """
+    name = "update"
+    description = "Updates Poetry to the latest version."
 
-    BASE_URL = "https://github.com/sdispater/poetry/releases/download"
+    arguments = [argument("version", "The version to update to.", optional=True)]
+    options = [option("preview", None, "Install prereleases.")]
+
+    REPOSITORY_URL = "https://github.com/python-poetry/poetry"
+    BASE_URL = REPOSITORY_URL + "/releases/download"
+    FALLBACK_BASE_URL = "https://github.com/sdispater/poetry/releases/download"
 
     @property
     def home(self):
@@ -51,7 +56,6 @@ class SelfUpdateCommand(Command):
         from poetry.repositories.pypi_repository import PyPiRepository
         from poetry.semver import Version
         from poetry.utils._compat import Path
-        from poetry.utils._compat import decode
 
         current = Path(__file__)
         try:
@@ -104,20 +108,7 @@ class SelfUpdateCommand(Command):
             self.line("You are using the latest version")
             return
 
-        try:
-            self.update(release)
-        except subprocess.CalledProcessError as e:
-            self.line("")
-            self.output.block(
-                [
-                    "[CalledProcessError]",
-                    "An error has occured: {}".format(str(e)),
-                    decode(e.output),
-                ],
-                style="error",
-            )
-
-            return e.returncode
+        self.update(release)
 
     def update(self, release):
         version = release.version
@@ -162,8 +153,17 @@ class SelfUpdateCommand(Command):
 
         checksum = "poetry-{}-{}.sha256sum".format(version, platform)
 
+        base_url = self.BASE_URL
         try:
-            r = urlopen(self.BASE_URL + "/{}/{}".format(version, checksum))
+            urlopen(self.REPOSITORY_URL)
+        except HTTPError as e:
+            if e.code == 404:
+                base_url = self.FALLBACK_BASE_URL
+            else:
+                raise
+
+        try:
+            r = urlopen(base_url + "/{}/{}".format(version, checksum))
         except HTTPError as e:
             if e.code == 404:
                 raise RuntimeError("Could not find {} file".format(checksum))
@@ -175,7 +175,7 @@ class SelfUpdateCommand(Command):
         # We get the payload from the remote host
         name = "poetry-{}-{}.tar.gz".format(version, platform)
         try:
-            r = urlopen(self.BASE_URL + "/{}/{}".format(version, name))
+            r = urlopen(base_url + "/{}/{}".format(version, name))
         except HTTPError as e:
             if e.code == 404:
                 raise RuntimeError("Could not find {} file".format(name))
